package com.hai.config;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.utils.HttpsUtils;
import com.hai.common.utils.WxUtils;
import com.hai.entity.EtcCarMsg;
import com.hai.entity.EtcCustMsg;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.context.annotation.Configuration;

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.*;

/**
 * @serviceName QrCodeUtilsConfig.java
 * @author Sum1Dream
 * @version 1.0.0
 * @Description // Etc申请管理
 * @createTime 09:54 2022/4/13
 **/
@Configuration 
public class EtcService {

    /**
    * @Author Sum1Dream
    * @Name submitCustInfo
    * @Description // 客户信息提交
    * @Date 16:31 2024/3/25
    * @Param etcCustMsg
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject submitCustInfo(EtcCustMsg etcCustMsg) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custName" , etcCustMsg.getCustName());
        jsonObject.put("custIdNo" , etcCustMsg.getCustIdNo());
        jsonObject.put("accountNo" , etcCustMsg.getAccountNo());
        jsonObject.put("bankName" , etcCustMsg.getBankName());
        jsonObject.put("address" , etcCustMsg.getAddress());
        jsonObject.put("phone" , etcCustMsg.getPhone());
        jsonObject.put("custAgentIdFront" , convertToBase64(etcCustMsg.getCustAgentIdFront()));
        jsonObject.put("custAgentIdBack" , convertToBase64(etcCustMsg.getCustAgentIdBront()));
        jsonObject.put("bankCard" , convertToBase64(etcCustMsg.getCustAgentIdBront()));
        if (etcCustMsg.getCustId() != null) {
            jsonObject.put("custId" , etcCustMsg.getCustId());
        }
        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/submitCustInfo" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name submitVehInfo
    * @Description // 车辆信息提交接口
    * @Date 11:28 2024/3/26
    * @Param etcCustMsg
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject submitVehInfo(EtcCarMsg etcCarMsg) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("productId" , etcCarMsg.getProductId());
        jsonObject.put("custId" , etcCarMsg.getCustId());
        jsonObject.put("cardVarietyId" , etcCarMsg.getCardVarietyId());

        List<JSONObject> vehInfoList = new ArrayList<>();
        JSONObject vehInfoListObject = new JSONObject();
        vehInfoListObject.put("vehPlateNo" , etcCarMsg.getVehPlateNo());
        vehInfoListObject.put("vehPlateColor" , etcCarMsg.getVehPlateColor());
        vehInfoListObject.put("vehType" , etcCarMsg.getVehType());
        vehInfoListObject.put("wheelsNum" , etcCarMsg.getWheelsNum());
        jsonObject.put("drivLicMainFro" , convertToBase64(etcCarMsg.getDrivlicMainFro()));
        jsonObject.put("drivLicSubFro" , convertToBase64(etcCarMsg.getDrivlicSubFro()));
        jsonObject.put("headStockPhoto" , convertToBase64(etcCarMsg.getHeadStockPhoto()));

        if (etcCarMsg.getVehId() != null) {
            jsonObject.put("vehId" , etcCarMsg.getVehId());
        }
        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/submitVehInfo" , map);
    }


    /**
    * @Author Sum1Dream
    * @Name getVehStatus
    * @Description // 查询车辆状态
    * @Date 13:54 2024/3/26
    * @Param etcCarMsg
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject getVehStatus(EtcCarMsg etcCarMsg) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , etcCarMsg.getCustId());
        jsonObject.put("vehId" , etcCarMsg.getVehId());

        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/getVehStatus" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name sendRealNameCode
    * @Description // 实名认证发送认证码接口
    * @Date 14:14 2024/3/26 
    * @Param JSONObject
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject sendRealNameCode(String custId) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);

        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/sendRealNameCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name checkRealNameCode
    * @Description // 实名认证核验验证码接口
    * @Date 14:16 2024/3/26
    * @Param object
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject checkRealNameCode(String custId , String verifyCode) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);
        jsonObject.put("verifyCode" , verifyCode);

        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/checkRealNameCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name sendSignVerifyCode
    * @Description // 签约验证码发送接口
    * @Date 14:37 2024/3/26 
    * @Param custId 
     * @Param verifyCode  
     * @return com.alibaba.fastjson.JSONObject
    */
    public static JSONObject sendSignVerifyCode(String custId) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);

        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/sendSignVerifyCode" , map);
    }


    public static JSONObject checkSignVerifyCode(String custId , String verifyCode) throws Exception {
        // 组装数据
        Map<String , Object> map = new HashMap<>();
        map.put("orgCode" , CommonSysConst.getSysConfig().getNdOrgCode());
        map.put("timestamps", System.currentTimeMillis());
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("custId" , custId);
        jsonObject.put("verifyCode" , verifyCode);

        String sign =  WxUtils.generateSignKytc(jsonObject , CommonSysConst.getSysConfig().getNdKey());

        map.put("body" , jsonObject);
        map.put("sign" , DigestUtils.md5Hex((sign).getBytes()));
        return HttpsUtils.doGet(CommonSysConst.getSysConfig().getDiandianwPostUrl()+"/api/v1/checkSignVerifyCode" , map);
    }

    /**
    * @Author Sum1Dream
    * @Name convertToBase64
    * @Description // 转换base64
    * @Date 16:32 2024/3/25
    * @Param imagePath
     * @return java.lang.String
    */
    public static String convertToBase64(String imagePath) {
        String base64Image = "";
        try {
            Path path = Paths.get( CommonSysConst.getSysConfig().getFileUrl() + imagePath);
            byte[] imageBytes = Files.readAllBytes(path);
            base64Image = Base64.getEncoder().encodeToString(imageBytes);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return base64Image;
    }







}
